The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Package {sylly.en}


Type: Package
Title: Language Support for 'sylly' Package: English
Depends: R (≥ 3.1),sylly
Description: Adds support for the English language to the 'sylly' package. To ask for help, report bugs, suggest feature improvements, or discuss the global development of the package, please consider subscribing to the koRpus-dev mailing list (https://korpusml.reaktanz.de).
License: GPL (≥ 3)
Encoding: UTF-8
LazyLoad: yes
URL: https://reaktanz.de/?c=hacking&s=sylly
BugReports: https://github.com/unDocUMeantIt/sylly.en/issues
Version: 0.1-4
Date: 2026-08-31
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-08-31 11:40:07 UTC; m
Author: Meik Michalke [aut, cre]
Maintainer: Meik Michalke <meik.michalke@hhu.de>
Repository: CRAN
Date/Publication: 2026-08-31 19:30:27 UTC

Language Support for 'sylly' Package: English

Description

Adds support for the English language to the 'sylly' package. To ask for help, report bugs, suggest feature improvements, or discuss the global development of the package, please consider subscribing to the koRpus-dev mailing list (<https://korpusml.reaktanz.de>).

Details

The DESCRIPTION file:

Package: sylly.en
Type: Package
Version: 0.1-4
Date: 2026-08-31
Depends: R (>= 3.1),sylly
Encoding: UTF-8
License: GPL (>= 3)
LazyLoad: yes
URL: https://reaktanz.de/?c=hacking&s=sylly

Author(s)

Meik Michalke [aut, cre]

Maintainer: Meik Michalke <meik.michalke@hhu.de>

See Also

Useful links:


Hyphenation patterns for English

Description

Hyphenation patterns for English to be used by hyphen. These data objects are not really intended to be used directly, but rather to be consulted by the hyphen() function without further user interaction.

Format

The pattern slot of each hyphenation pattern object has three colums:

orig

The original pattern in patgen style format.

char

Only the character elements of the pattern which can be matched to parts of an actual word.

nums

A code of digits defining the possibility to split syllables at respective places in this pattern.

The patterns (as they are present in the "orig" column described above) were originally provided by the LaTeX developers[1], under the terms of the LaTeX Project Public License[2]. Refer to Liang (1983) for a detailed explaination. From these original patterns the values in the remaining columns were created using read.hyph.pat.

In case any changes to the patterns were necessary to be used in this package, they are documented in the ChangeLog for the sources package. The unchanged original patterns can be found under [1].

References

Liang, F.M. (1983). Word Hy-phen-a-tion by Com-put-er. Dissertation, Stanford University, Dept. of Computer Science.

[1] https://ctan.org/tex-archive/language/hyph-utf8/tex/patterns/txt/

[2] https://www.ctan.org/tex-archive/macros/latex/base/lppl.txt

See Also

read.hyph.pat, manage.hyph.pat

Examples

library(sylly.en)
sampleText <- c("This", "is", "a", "rather", "stupid", "demonstration")
hyphen(sampleText, hyph.pattern="en")

Language support for English

Description

This function adds support for English to the sylly package. You should not need to call it manually, as that is done automatically when this package is loaded.

Usage

hyph.support.en()

Details

In particular, a new set of hyphenation patterns is being added (see hyph.en). To use the patterns with hyphen, simply use the abbreviation:

"en"

— English hyphenation patterns (UK)

"en.us"

— English hyphenation patterns (US)

See Also

hyphen, set.hyph.support

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.